@@ -20,40 +20,32 @@
 #include <sys/stat.h>
 #include "appdata.h"
 
-static const char *icon_paths[] = {
-  "/usr/share/" PACKAGE "/icons" ,   // final installation path 
-  "./data/icons",                    // local path for testing
-  ""
-};
-
 static const char *icon_exts[] = {
   "gif", "png", "jpg", ""
 };
 
 static gchar*
-icon_file_exists(const gchar *dir, const gchar *file) {
-  gchar *fullname;
-  struct stat s;
-  gint status, idx;
+icon_file_exists(const gchar *file) {
+  gchar *filename, *fullname;
+  gint idx = 0;
 
-  idx = 0;
   while(icon_exts[idx][0]) {
-    fullname = g_strdup_printf("%s/%s.%s", dir, file, icon_exts[idx]);
-    status = stat(fullname, &s);
-    if(status == 0 && S_ISREG(s.st_mode))
+    filename = g_strdup_printf("icons/%s.%s", file, icon_exts[idx]);
+    fullname = find_file(filename);
+    g_free(filename);
+    
+    if(fullname)
       return fullname;
 
     idx++;
-    g_free(fullname);
   }
   return NULL;
 }
 
-GdkPixbuf *icon_load(appdata_t *appdata, const char *name) {
+GdkPixbuf *icon_load(icon_t **icon, const char *name) {
   if(!name) return NULL;
 
   /* check if icon list already contains an icon of that name */
-  icon_t **icon = &(appdata->icon);
   while(*icon) {
     if(strcmp(name, (*icon)->name) == 0) {
       //      printf("reuse existing icon\n");
@@ -64,39 +56,32 @@ GdkPixbuf *icon_load(appdata_t *appdata, const char *name) {
     icon = &((*icon)->next);
   }
 
-  gint i=0;
-  do {
-    gchar *fullname = icon_file_exists(icon_paths[i], name);
-    if(fullname) {
-      GdkPixbuf *pix = gdk_pixbuf_new_from_file(fullname, NULL);
-      g_free(fullname);
-
-      //      printf("Successfully loaded icon %s to %p\n", name, pix);
+  gchar *fullname = icon_file_exists(name);
+  if(fullname) {
+    GdkPixbuf *pix = gdk_pixbuf_new_from_file(fullname, NULL);
+    g_free(fullname);
+    
+    //      printf("Successfully loaded icon %s to %p\n", name, pix);
       *icon = g_new0(icon_t, 1);
       (*icon)->name = strdup(name);
       (*icon)->buf = pix;
       (*icon)->use = 1;
-
+      
       return pix;
-    }
-
-    i++;
-  } while(icon_paths[i][0]);
+  }
 
   printf("Icon %s not found\n", name);
   return NULL;
 }
 
-GtkWidget *icon_widget_load(appdata_t *appdata, const char *name) {
-  GdkPixbuf *pix = icon_load(appdata, name);
+GtkWidget *icon_widget_load(icon_t **icon, const char *name) {
+  GdkPixbuf *pix = icon_load(icon, name);
   if(!pix) return NULL;
 
   return gtk_image_new_from_pixbuf(pix);
 }
 
-void icon_free(appdata_t *appdata, GdkPixbuf *buf) {
-  icon_t **icon = &(appdata->icon);
-
+void icon_free(icon_t **icon, GdkPixbuf *buf) {
   //  printf("request to free icon %p\n", buf);
 
   while(*icon) {
@@ -105,7 +90,7 @@ void icon_free(appdata_t *appdata, GdkPixbuf *buf) {
     if(buf == (*icon)->buf) {
       (*icon)->use--;
       if(!(*icon)->use) {
-	printf("freeing unused icon\n");
+	printf("freeing unused icon %s\n", (*icon)->name);
 
 	g_free((*icon)->name);
 	gdk_pixbuf_unref((*icon)->buf);
@@ -114,7 +99,8 @@ void icon_free(appdata_t *appdata, GdkPixbuf *buf) {
 	*icon = next;
 
       } else 
-	printf("keeping icon still in use by %d\n", (*icon)->use);
+	printf("keeping icon %s still in use by %d\n", 
+	       (*icon)->name, (*icon)->use);
 
       return;
     }
@@ -124,9 +110,8 @@ void icon_free(appdata_t *appdata, GdkPixbuf *buf) {
   printf("ERROR: icon to be freed not found\n");
 }
 
-void icon_free_all(appdata_t *appdata) {
-  icon_t *icon = appdata->icon;
-
+void icon_free_all(icon_t **icons) {
+  icon_t *icon = *icons;
   while(icon) {
     g_free(icon->name);
     gdk_pixbuf_unref(icon->buf);
@@ -135,5 +120,5 @@ void icon_free_all(appdata_t *appdata) {
     icon = next;
   }
 
-  appdata->icon = NULL;
+  *icons = NULL;
 }
