@@ -20,6 +20,9 @@
 #ifndef JOSM_PRESETS_H
 #define JOSM_PRESETS_H
 
+// set this if _all_ josm icons are in data/presets
+// #define JOSM_PATH_ADJUST
+
 typedef enum {
   WIDGET_TYPE_LABEL = 0,
   WIDGET_TYPE_SEPARATOR,
@@ -82,6 +85,7 @@ typedef struct presets_item_s {
 
 presets_item_t *josm_presets_load(void);
 GtkWidget *josm_presets_select(appdata_t *appdata, tag_context_t *tag_context);
-void josm_presets_clear(presets_item_t *presets);
+void josm_presets_free(presets_item_t *presets);
+char *josm_icon_name_adjust(char *name);
 
 #endif // JOSM_PRESETS_H
