@@ -67,10 +67,9 @@ cb_menu_download(GtkWidget *window, gpointer data) {
   if(!appdata->osm || !appdata->project) return;
 
   /* redraw the entire map by destroying all map items and redrawing them */
-  track_save(appdata->project, appdata->track.track);
   diff_save(appdata->project, appdata->osm);
-  map_clear(appdata);
-  osm_free(appdata->osm);
+  map_clear(appdata, MAP_LAYER_OBJECTS_ONLY);
+  osm_free(&appdata->icon, appdata->osm);
 
   // download
   osm_download(GTK_WIDGET(appdata->window), appdata->project);
@@ -78,12 +77,6 @@ cb_menu_download(GtkWidget *window, gpointer data) {
   appdata->osm = osm_parse(appdata->project->osm);
   diff_restore(appdata, appdata->project, appdata->osm);
   map_paint(appdata);
-
-  appdata->track.track = track_restore(appdata, appdata->project);
-  if(appdata->track.track)
-    map_track_draw(appdata->map, appdata->track.track);
-
-  wms_load(appdata);
 }
 
 static void 
@@ -128,8 +121,8 @@ cb_menu_redraw(GtkWidget *window, gpointer data) {
   /* redraw the entire map by destroying all map items and redrawing them */
   track_save(appdata->project, appdata->track.track);
   diff_save(appdata->project, appdata->osm);
-  map_clear(appdata);
-  osm_free(appdata->osm);
+  map_clear(appdata, MAP_LAYER_ALL);
+  osm_free(&appdata->icon, appdata->osm);
 
   appdata->osm = osm_parse(appdata->project->osm);
   diff_restore(appdata, appdata->project, appdata->osm);
@@ -143,6 +136,13 @@ cb_menu_redraw(GtkWidget *window, gpointer data) {
 }
 #endif
 
+static void 
+cb_menu_style(GtkWidget *window, gpointer data) {
+  appdata_t *appdata = (appdata_t*)data;
+
+  style_select(GTK_WIDGET(appdata->window), appdata);
+}
+
 static void 
 cb_menu_save_changes(GtkWidget *window, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
@@ -255,7 +255,7 @@ cb_menu_track_clear(GtkWidget *window, gpointer data) {
 }
 
 void menu_create(appdata_t *appdata) { 
-  GtkWidget *menu, *item, *submenu;  
+  GtkWidget *menu, *item, *submenu;
   menu = gtk_menu_new();
 
 #ifdef USE_HILDON
@@ -354,6 +354,12 @@ void menu_create(appdata_t *appdata) {
   gtk_menu_append(GTK_MENU_SHELL(submenu), item);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_redraw), appdata);
 
+  gtk_menu_append(GTK_MENU_SHELL(submenu), gtk_separator_menu_item_new());
+
+  item = gtk_menu_item_new_with_label( _("Style") );
+  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
+  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_style), appdata);
+
   /* -------------------- track submenu -------------------- */
 
   item = gtk_menu_item_new_with_label( _("Track") );
@@ -420,6 +426,8 @@ void menu_create(appdata_t *appdata) {
 
 
 void cleanup(appdata_t *appdata) {
+  settings_save(appdata->settings);
+
 #ifdef USE_HILDON
   if(appdata->osso_context)
     osso_deinitialize(appdata->osso_context);
@@ -443,16 +451,18 @@ void cleanup(appdata_t *appdata) {
 
   map_remove_bg_image(appdata->map);
 
-  osm_free(appdata->osm);
+  osm_free(&appdata->icon, appdata->osm);
 
   curl_global_cleanup();
 
-  josm_presets_clear(appdata->presets);
+  josm_presets_free(appdata->presets);
 
-  icon_free_all(appdata);
+  icon_free_all(&appdata->icon);
 
   gps_release(appdata);
 
+  settings_free(appdata->settings);
+
   puts("everything is gone");
 }
 
@@ -550,7 +560,7 @@ int main(int argc, char *argv[]) {
   gtk_window_set_title(GTK_WINDOW(appdata.window), "OSM2Go");
   /* Set a decent default size for the window. */
   gtk_window_set_default_size(GTK_WINDOW(appdata.window), 640, 480);
-  gtk_window_set_icon(GTK_WINDOW(appdata.window), icon_load(&appdata, "osm2go"));
+  gtk_window_set_icon(GTK_WINDOW(appdata.window), icon_load(&appdata.icon, "osm2go"));
 #endif
 
   g_signal_connect(G_OBJECT(appdata.window), "destroy", 
@@ -565,9 +575,6 @@ int main(int argc, char *argv[]) {
   /* user specific init */
   appdata.settings = settings_load();  
 
-  /* load potlatch config files to resemble potlatch view */
-  appdata.potlatch = potlatch_conf_load();
-
   /* ----------------------- setup main window ---------------- */
 
   GtkWidget *hbox = gtk_hbox_new(FALSE,0);
