@@ -22,29 +22,15 @@
 
 #include "osm.h"
 
-/* -------- all sizes are in meters ---------- */
-#define DARK_GREY        CANVAS_COLOR(0x60,0x60,0x60,0xff)
-#define WAY_WIDTH        3.0
-#define STROKE_WIDTH     6.0
-#define RADIUS           4.0          // stand-alone nodes
-#define S_RADIUS         4.0          // nodes with tags (!= created_by)
-#define MAP_COLOR_NONE   0x0
-#define FILL_TRANSP      0x60
-#define DEF_FILL_COLOR   CANVAS_COLOR(0xc0,0xc0,0xc0,FILL_TRANSP)
-#define NODE_COLOR       CANVAS_COLOR(0x00,0x88,0x00,0xff)
-#define NODE_WAY_COLOR   CANVAS_COLOR(0x00,0x00,0x00,0xff)
-#define HIGHLIGHT_COLOR  CANVAS_COLOR(0xff,0xff,0x00,0x80)  // stand alone nodes and ways
-#define HIGHLIGHT2_COLOR CANVAS_COLOR(0xff,0x00,0x00,0x80)  // nodes of a selected way
-#define TOUCHNODE_COLOR  CANVAS_COLOR(0x00,0x00,0xff,0x80)  // node touched during drag
-#define TRACK_COLOR      CANVAS_COLOR(0x00,0x00,0xff,0x40)  // track
-#define TRACK_GPS_COLOR  CANVAS_COLOR(0x00,0x00,0x80,0xff)  // gps
-#define NO_COLOR         CANVAS_COLOR(0x00,0x00,0x00,0x00)  
+#define MAP_LAYER_ALL (0xffff)
+#define MAP_LAYER_OBJECTS_ONLY ((1<<CANVAS_GROUP_POLYGONS) | (1<<CANVAS_GROUP_WAYS_HL) | (1<<CANVAS_GROUP_WAYS_OL) | (1<<CANVAS_GROUP_WAYS) | (1<<CANVAS_GROUP_NODES_HL) | (1<<CANVAS_GROUP_NODES))
 
-// frisket masking non-editable areas
-#define FRISKET_COLOR    CANVAS_COLOR(0xff,0xff,0xff,0xff)  // frisket itself
-#define FRISKET_EDGE_COLOR CANVAS_COLOR(0x00,0x00,0x00,0x99)  // frisket edge
-#define FRISKET_EDGE_WIDTH 6.0  // canvas units
-#define FRISKET_MULT       3.0 // times the map size
+/* -------- all sizes are in meters ---------- */
+#define MAP_COLOR_NONE   0x0
+#define NO_COLOR         CANVAS_COLOR(0x00,0x00,0x00,0x00)
+
+#define RGB2CANVAS(a)    (((a)<<8) | 0xff) 
+#define RGBA2CANVAS(a,b) (((a)<<8) | (b)) 
 
 #define ZOOM_FACTOR_MENU   (1.5)
 #define ZOOM_FACTOR_WHEEL  (1.1)
@@ -55,7 +41,7 @@
 /* to prevent accidential dragging when the user only intended to click */
 /* something. This is especially useful when using a touchscreen. */
 #ifndef USE_HILDON
-#define MAP_DRAG_LIMIT   8
+#define MAP_DRAG_LIMIT   4
 #else
 #define MAP_DRAG_LIMIT   16
 #endif
@@ -155,6 +141,7 @@ typedef struct map_s {
                                 // (may be part of a selected way)
   } pen_down;
 
+  struct style_s *style;
 
 } map_t;
 
@@ -169,7 +156,7 @@ void map_highlight_refresh(appdata_t *appdata);
 
 void map_item_redraw(appdata_t *appdata, map_item_t *map_item);
 
-void map_clear(appdata_t *appdata);
+void map_clear(appdata_t *appdata, gint layer_mask);
 void map_paint(appdata_t *appdata);
 
 void map_action_set(appdata_t *appdata, map_action_t action);
@@ -202,7 +189,6 @@ void map_item_chain_destroy(map_item_chain_t **chainP);
 map_item_t *map_item_at(map_t *map, gint x, gint y);
 void map_item_deselect(appdata_t *appdata);
 void map_way_delete(appdata_t *appdata, way_t *way);
-void map_way_color(potlatch_conf_t *potlatch, way_t *way);
 void map_way_draw(map_t *map, way_t *way);
 void map_way_select(appdata_t *appdata, way_t *way);
 void map_outside_error(appdata_t *appdata);
