@@ -31,6 +31,9 @@ typedef gulong item_id_t;
 
 #define ID_ILLEGAL  ((item_id_t)0)
 
+/* icon stuff is required since nodes may held a icon reference */
+struct icon_s;
+
 typedef struct bounds_s {
   pos_t ll_min, ll_max;
   lpos_t min, max;
@@ -59,6 +62,9 @@ typedef struct node_s {
   int ways;
   int flags;
 
+  /* icon */
+  GdkPixbuf *icon_buf;
+
   /* a link to the visual representation on screen */
   struct map_item_chain_s *map_item_chain;
 
@@ -70,8 +76,8 @@ typedef struct node_chain {
   struct node_chain *next;
 } node_chain_t;
 
-#define OSM_DRAW_FLAG_POLYGON  (1<<0)
-#define OSM_DRAW_FLAG_STROKE   (1<<1)
+#define OSM_DRAW_FLAG_AREA  (1<<0)
+#define OSM_DRAW_FLAG_BG    (1<<1)
 
 typedef struct way_s {
   item_id_t id;
@@ -82,10 +88,24 @@ typedef struct way_s {
   node_chain_t *node_chain;
   int flags;
 
-  /* visual representation from potlatch conf */
-  guint color, fill_color;
-  guint draw_flags;
+  /* visual representation from elemstyle */
+  struct {
+    guint flags;
+    gulong color;
+    gint width;
 
+    union {
+      struct {
+	gulong color;
+	gint width;
+      } bg;
+      
+      struct {
+	gulong color;
+      } area;
+    };     
+  } draw;
+  
   /* a link to the visual representation on screen */
   struct map_item_chain_s *map_item_chain;
 
@@ -149,7 +169,7 @@ tag_t *osm_parse_osm_tag(osm_t *osm, xmlDocPtr doc, xmlNode *a_node);
 node_chain_t *osm_parse_osm_way_nd(osm_t *osm, xmlDocPtr doc, xmlNode *a_node);
 member_t *osm_parse_osm_relation_member(osm_t *osm, xmlDocPtr doc, xmlNode *a_node);
 void osm_dump(osm_t *osm);
-void osm_free(osm_t *osm);
+void osm_free(struct icon_s **icon, osm_t *osm);
 
 char *osm_node_get_value(node_t *node, char *key);
 gboolean osm_node_has_tag(node_t *node);
@@ -158,16 +178,16 @@ void osm_node_dump(node_t *node);
 
 void osm_way_free(way_t *way);
 void osm_way_dump(way_t *way);
-gboolean osm_way_is_way(way_t *way);
 char *osm_way_get_value(way_t *way, char *key);
-gboolean osm_way_has_key_or_value(way_t *way, char *str);
+gboolean osm_node_has_value(node_t *node, char *str);
+gboolean osm_way_has_value(way_t *way, char *str);
 void osm_way_append_node(way_t *way, node_t *node);
 
 gboolean osm_node_in_way(way_t *way, node_t *node);
 
 void osm_node_chain_free(node_chain_t *node_chain);
 int osm_node_chain_length(node_chain_t *node_chain);
-void osm_node_free(node_t *node);
+void osm_node_free(struct icon_s **icon, node_t *node);
 
 void osm_members_free(member_t *member);
 void osm_member_free(member_t *member);
@@ -195,9 +215,10 @@ way_chain_t *osm_node_to_way(osm_t *osm, node_t *node);
 /* ----------- edit functions ----------- */
 node_t *osm_node_new(osm_t *osm, gint x, gint y);
 void osm_node_attach(osm_t *osm, node_t *node);
-way_chain_t *osm_node_delete(osm_t *osm, node_t *node, gboolean permanently,
-			     gboolean affect_ways);
-void osm_way_delete(osm_t *osm, way_t *way, gboolean permanently);
+way_chain_t *osm_node_delete(osm_t *osm, struct icon_s **icon, node_t *node, 
+			     gboolean permanently, gboolean affect_ways);
+void osm_way_delete(osm_t *osm, struct icon_s **icon, way_t *way, 
+		    gboolean permanently);
 
 way_t *osm_way_new(void);
 void osm_way_attach(osm_t *osm, way_t *way);
