@@ -85,15 +85,6 @@ static gboolean project_read(appdata_t *appdata,
 	      printf("server = %s\n", project->server);
 	      xmlFree(str);
 	      
-	      if((str = (char*)xmlGetProp(node, BAD_CAST "username"))) {
-		project->username = g_strdup(str);
-		xmlFree(str);
-	      } 
-	      if((str = (char*)xmlGetProp(node, BAD_CAST "password"))) {
-		project->password = g_strdup(str);
-		xmlFree(str);
-	      } 
-
 	    } else if(project->map_state && 
 		      strcasecmp((char*)node->name, "map") == 0) {
 	      if((str = (char*)xmlGetProp(node, BAD_CAST "zoom"))) {
@@ -200,8 +191,6 @@ gboolean project_save(GtkWidget *parent, project_t *project) {
 
   node = xmlNewChild(root_node, NULL, BAD_CAST "server", 
 		     BAD_CAST project->server);
-  xmlNewProp(node, BAD_CAST "username", BAD_CAST project->username);
-  xmlNewProp(node, BAD_CAST "password", BAD_CAST project->password);
 
   xmlNewChild(root_node, NULL, BAD_CAST "desc", BAD_CAST project->desc);
   xmlNewChild(root_node, NULL, BAD_CAST "osm", BAD_CAST project->osm);
@@ -252,9 +241,6 @@ void project_free(project_t *project) {
   if(project->desc)       g_free(project->desc);
   if(project->server)     g_free(project->server);
 
-  if(project->username)   g_free(project->username);
-  if(project->password)   g_free(project->password);
- 
   if(project->wms_server) g_free(project->wms_server);
   if(project->wms_path)   g_free(project->wms_path);
  
@@ -527,8 +513,6 @@ project_t *project_new(select_context_t *context) {
 
   /* use global server/access settings */
   project->server   = g_strdup(context->settings->server);
-  project->username = g_strdup(context->settings->username);
-  project->password = g_strdup(context->settings->password);
   
   /* dito for wms settings */
   project->wms_server = g_strdup(context->settings->wms_server);
@@ -545,7 +529,8 @@ project_t *project_new(select_context_t *context) {
   project_save(context->dialog, project);
 
 #ifdef USE_HILDON
-  if(!project_edit(context->dialog, project, context->mmpos, context->osso_context))
+  if(!project_edit(context->dialog, project, context->mmpos, 
+		   context->osso_context))
 #else
   if(!project_edit(context->dialog, project))
 #endif
@@ -594,7 +579,7 @@ static void on_project_delete(GtkButton *button, gpointer data) {
 	     GTK_DIALOG_DESTROY_WITH_PARENT,
 	     GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
   g_free(str);
-      
+
   gtk_window_set_title(GTK_WINDOW(dialog), _("Delete project?"));
       
   /* set the active flag again if the user answered "no" */
