@@ -28,9 +28,6 @@ typedef struct project_s {
   char *server;
   char *osm;
 
-  char *username;
-  char *password;
-
   char *wms_server;
   char *wms_path;
   struct { gint x, y; } wms_offset;
