@@ -20,6 +20,7 @@
 #ifndef SETTINGS_H
 #define SETTINGS_H
 
+/* default working directory */
 #ifndef USE_HILDON
 #define BASE_DIR ".osm2go/"
 #else
@@ -27,6 +28,7 @@
 #endif
 
 typedef struct settings_s {
+
   /* never changed */
   char *base_path;
 
@@ -36,8 +38,13 @@ typedef struct settings_s {
   /* changed in wms.c */
   char *wms_server, *wms_path;
 
+  /* changed in style.c */
+  char *style;
+
 } settings_t;
 
 settings_t *settings_load(void);
+void settings_save(settings_t *settings);
+void settings_free(settings_t *settings);
 
 #endif // SETTINGS_H
