@@ -548,8 +548,9 @@ static gboolean wms_server_dialog(appdata_t *appdata, wms_t *wms) {
   
   GtkWidget *dialog = gtk_dialog_new_with_buttons(_("WMS Setup"),
 	  GTK_WINDOW(appdata->window), GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+          NULL);
 
 #ifdef USE_HILDON
   /* making the dialog a little wider makes it less "crowded" */
@@ -706,8 +707,9 @@ static gboolean wms_layer_dialog(appdata_t *appdata, wms_layer_t *layer) {
 
   GtkWidget *dialog = gtk_dialog_new_with_buttons(_("WMS layer selection"),
 	  GTK_WINDOW(appdata->window), GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+          NULL);
 
   gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), 
 				    GTK_RESPONSE_ACCEPT, FALSE);
